.. image:: https://badge.fury.io/py/labml-helpers.svg
    :target: https://badge.fury.io/py/labml-helpers
.. image:: https://pepy.tech/badge/labml_helpers
    :target: https://pepy.tech/project/labml_helpers

LabML Helpers
=============

This is a collection of classes and functions to automate common deep learning training patterns. This was originally part of 
`labml <https://github.com/lab-ml/labml>`_, and was moved out as it grew larger.

Installation
------------

.. code-block:: console

    pip install labml-helpers

Links
-----

`💬 Slack workspace for discussions <https://join.slack.com/t/labforml/shared_invite/zt-egj9zvq9-Dl3hhZqobexgT7aVKnD14g/>`_

`📗 Documentation <http://lab-ml.com/>`_

`📑 Articles & Tutorials <https://medium.com/@labml/>`_

`👨‍🏫 Samples <https://github.com/lab-ml/samples>`_


Citing LabML
------------

If you use LabML for academic research, please cite the library using the following BibTeX entry.

.. code-block:: bibtex

	@misc{labml,
	 author = {Varuna Jayasiri, Nipun Wijerathne},
	 title = {LabML: A library to organize machine learning experiments},
	 year = {2020},
	 url = {https://lab-ml.com/},
	}

